@@ -10,3 +10,10 @@ from .bounding_box import *
 from .image_crop import *
 from .pbs_plan_file import dicom_rt_pbs_plan_to_gate_conversion
 from .logging_conf import logging_conf, add_options, common_options
+from .affine_transform import *
+from .image_statistics import *
+from .write_dicom import *
+from .gauss_filter import *
+from .image_resize import *
+from .dvh import *
+from .merge_root import *
